from enum import Enum

class HttpMethod(str, Enum):
    GET = 'GET'
    POST = 'POST'
    PATCH = 'PATCH'